==================================
Zun CLI Documentation (source/cli)
==================================


This directory is intended to hold any documentation that relates to
Zun's Command Line Interface. Note that this directory is intended for
basic descriptions of the commands supported, similar to what you would
find with a 'man page'. Tutorials or step-by-step guides should go into
'doc/source/admin' or 'doc/source/user' depending on the target audience.
